@@ -304,22 +304,22 @@ void FoodInput::CalcSize()
           ->Add(Lum::Button::Create(L"_Clear",clearFilterAction,false,true))
           ->AddSpace()
           ->Add(Lum::Button::Create(L"+",
-                                    Lum::OS::display->GetTheme()->GetStockImage(Lum::OS::Theme::addStockImage),
+                                    Lum::OS::Theme::imageAdd,
                                     addFoodEntryAction,
                                     Lum::Button::typeIcon))
           ->Add(new Lum::HSpace(Lum::Space::sizeSmall))
           ->Add(Lum::Button::Create(L"-",
-                                    Lum::OS::display->GetTheme()->GetStockImage(Lum::OS::Theme::removeStockImage),
+                                    Lum::OS::Theme::imageRemove,
                                     removeFoodEntryAction,
                                     Lum::Button::typeIcon))
           ->Add(new Lum::HSpace(Lum::Space::sizeSmall))
           ->Add(Lum::Button::Create(L"~",
-                                    Lum::OS::display->GetTheme()->GetStockImage(Lum::OS::Theme::editStockImage),
+                                    Lum::OS::Theme::imageEdit,
                                     editFoodEntryAction,
                                     Lum::Button::typeIcon))
           ->Add(new Lum::HSpace(Lum::Space::sizeSmall))
           ->Add(Lum::Button::Create(L"->",
-                                    Lum::OS::display->GetTheme()->GetStockImage(Lum::OS::Theme::positiveStockImage),
+                                    Lum::OS::Theme::imagePositive,
                                     registerFoodAction,
                                     Lum::Button::typeIcon))
           );
