@@ -46,7 +46,7 @@
 #include "Preferences.h"
 #include "Statistics.h"
 
-static Lum::AppInfo info;
+static Lum::Def::AppInfo info;
 
 class MainDialog : public Lum::Dialog
 {
